<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\MasterController;
use App\Models\Ad;
use App\Models\Admin;
use App\Models\Building;
use App\Models\BuildingDescription;
use App\Models\BuildingImage;
use App\Models\Category;
use App\Models\City;
use App\Models\CityDescription;
use App\Models\Client;
use App\Models\Country;
use App\Models\District;
use App\Models\DistrictDescription;
use App\Models\Language;
use App\Models\Product;
use App\Models\SubCategory;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
//use Illuminate\Support\Facades\Auth;
use Jenssegers\Agent\Agent;
use Analytics;
use Auth;
class BuildingController extends MasterController
{
    public function __construct(Building $model)
    {
        $this->model = $model;
        $this->route = 'building';
        $this->module_name         = 'قائمة العقارات';
        $this->single_module_name  = 'عقار';
        parent::__construct();
    }
    public function index() {
        $rows = $this->model->where('type','owner')->latest()->get();
        return view('admin.'.$this->route.'.index', compact('rows'));
    }

    public function validation_func()
    {
        $languages=Language::all();
        $therulesarray = [];
        foreach ( $languages as $language) {
            $therulesarray['address_'.$language->label] = 'required|max:255';
            $therulesarray['note_'.$language->label] = 'required';
        }
        $therulesarray['client_id'] = 'required';
        $therulesarray['rent'] = 'required';
        return $therulesarray;
    }

    public function store(Request $request) {
        $this->validate($request, $this->validation_func());
        $building=new Building();
        $building->add_by=request('add_by');
        $building->type='owner';
        $building->status=request('status');
        $building->building_type_id=request('building_type_id');
        $building->hiring_type_id=request('hiring_type_id');
        $building->district_id=request('district_id');
        $building->building_status_id=request('building_status_id');
        $building->client_id=request('client_id');
        if(request('lat')){
            $building->lat=request('lat');
            $building->long=request('long');
        }
        $building->rent=request('rent');
        $building->save();
        $languages=Language::all();
        foreach ($languages as $language){
            $building_description=new BuildingDescription();
            $building_description->name=request('name_'.$language->label);
            $building_description->address=request('address_'.$language->label);
            $building_description->note='<center>'.request('note_'.$language->label).'</center>';
            $building_description->language_id=$language->id;
            $building_description->building_id=$building->id;
            $building_description->save();
        }

        if($request->images){
            foreach ($request->images as $image){
                $building_image=new BuildingImage();
                $building_image->add_by=request('add_by');
                $building_image->building_id=$building->id;
                $building_image->name=$image;
                $building_image->save();
            }
        }

        return redirect('admin/'.$this->route.'')->with('created', 'تمت الاضافة بنجاح');
    }


    public function update($id, Request $request) {
        $this->validate($request, $this->validation_func());
        $building=$this->model->find($id);
        $building->status=request('status');
        $building->building_type_id=request('building_type_id');
        if(request('building_type_id')==2){
            $building->have_flats=1;
        }
        $building->hiring_type_id=request('hiring_type_id');
        $building->building_status_id=request('building_status_id');
        $building->client_id=request('client_id');
        if(request('lat')){
            $building->lat=request('lat');
            $building->long=request('long');
        }
        $building->rent=request('rent');
        $building->update();
        $languages=Language::all();
        foreach ($languages as $language){
            $building_description=BuildingDescription::where(['building_id'=>$id,'language_id'=>$language->id])->first();
            if(isset($building_description)){
                $building_description->name=request('name_'.$language->label);
                $building_description->address=request('address_'.$language->label);
                $building_description->note='<center>'.request('note_'.$language->label).'</center>';
                $building_description->update();
            }else{
                $building_description=new BuildingDescription();
                $building_description->name=request('name_'.$language->label);
                $building_description->address=request('address_'.$language->label);
                $building_description->note='<center>'.request('note_'.$language->label).'</center>';
                $building_description->language_id=$language->id;
                $building_description->building_id=$building->id;
                $building_description->save();
            }
        }
        if($request->images){
            $images=BuildingImage::where('building_id',$building->id)->get();
            foreach ($images as $image){
                $image->delete();
            }
            foreach ($request->images as $image){
                $building_image=new BuildingImage();
                $building_image->add_by=request('add_by');
                $building_image->building_id=$building->id;
                $building_image->name=$image;
                $building_image->save();
            }
        }
        return redirect('admin/'.$this->route.'')->with('updated','تم التعديل بنجاح');
    }



}
