<?php
namespace App\Http\Controllers\Admin;

use App\Http\Requests;
use App\Http\Controllers\Controller;
use App\Models\Ad;
use App\Models\Admin;
use App\Models\Bank;
use App\Models\Building;
use App\Models\BuildingDescription;
use App\Models\BuildingStatus;
use App\Models\BuildingStatusDescription;
use App\Models\BuildingType;
use App\Models\BuildingTypeDescription;
use App\Models\Category;
use App\Models\CategoryDescription;
use App\Models\City;
use App\Models\CityDescription;
use App\Models\Client;
use App\Models\Country;
use App\Models\CountryDescription;
use App\Models\District;
use App\Models\DistrictDescription;
use App\Models\Flat;
use App\Models\Hiring;
use App\Models\HiringType;
use App\Models\HiringTypeDescription;
use App\Models\Language;
use App\Models\Month;
use App\Models\MonthDescription;
use App\Models\Page;
use App\Models\Product;
use App\Models\Setting;
use App\Models\Social;
use App\Models\SubCategory;
use App\User;
use ConsoleTVs\Charts\Facades\Charts;
use Illuminate\Http\Request;
use Auth;
//use Analytics;
//use Spatie\Analytics\Period;

abstract class MasterController extends Controller {

    protected $model;         // model name
    protected $other_model;         // other_model name
    protected $route;         // route name
    protected $perPage = 10;  // pagination
    protected $validation_c;  // validation on create
    protected $validation_u;  // validation on update
    protected $module_name;
    protected $single_module_name;
    protected $index_fields;
    protected $create_fields;
    protected $update_fields;

    public function __construct()
    {
//        $chart=Charts::create('percentage', 'justgage')
//            ->title('My nice chart')
//            ->elementLabel('My nice label')
//            ->values([65,0,100])
//            ->responsive(false)
//            ->height(300)
//            ->width(0);
       // $analytics=new Analytics;
//        $analyticsData = Analytics::fetchVisitorsAndPageViews(Period::days(7));


        $cities_array = [];
        $cities=City::all();
        foreach ( $cities as $city) {
            $city_name=CityDescription::where(['language_id'=>1,'city_id'=>$city->id])->value('name');
            $cities_array[$city->id] = $city_name;
        }
        $districts_array = [];
        $districts=District::all();
        foreach ( $districts as $district) {
            $district_name=DistrictDescription::where(['language_id'=>1,'district_id'=>$district->id])->value('name');
            $districts_array[$district->id] = $district_name;
        }
        $building_statuses_array = [];
        $building_statuses=BuildingStatus::all();
        foreach ( $building_statuses as $building) {
            $building_status_name=BuildingStatusDescription::where(['language_id'=>1,'building_status_id'=>$building->id])->value('name');
            $building_statuses_array[$building->id] = $building_status_name;
        }
        $building_types_array = [];
        $building_types=BuildingType::all();
        foreach ( $building_types as $building) {
            $building_type_name=BuildingTypeDescription::where(['language_id'=>1,'building_type_id'=>$building->id])->value('name');
            $building_types_array[$building->id] = $building_type_name;
        }
        $hiring_types_array = [];
        $hiring_types=HiringType::all();
        foreach ( $hiring_types as $hiring) {
            $hiring_type_name=HiringTypeDescription::where(['language_id'=>1,'hiring_type_id'=>$hiring->id])->value('name');
            $hiring_types_array[$hiring->id] = $hiring_type_name;
        }
        $months_array = [];
        $months=Month::all();
        foreach ( $months as $month) {
            $month_name=MonthDescription::where(['language_id'=>1,'month_id'=>$month->id])->value('name');
            $months_array[$month->id] = $month_name;
        }
        $clients_array = [];
        $clients=Client::where('status','active')->get();
        foreach ( $clients as $client) {
            $clients_array[$client->id] = $client->name;
        }
        $buildings_array = [];
        $buildings=Building::where(['building_type_id'=>'2','type'=>'owner'])->get();
        foreach ( $buildings as $building) {
            $building_name=BuildingDescription::where(['building_id'=>$building->id,'language_id'=>1])->value('name');
            $buildings_array[$building->id] = $building_name;
        }

        $union_array = [];
        $union=Building::where(['type'=>'union'])->get();
        foreach ( $union as $building) {
            $building_name=BuildingDescription::where(['building_id'=>$building->id,'language_id'=>1])->value('name');
            $union_array[$building->id] = $building_name;
        }

        $not_hiring_buildings_array = [];
        $hiring=Hiring::where('building_id','!=',null)->pluck('building_id');
        $buildings=Building::where(['type'=>'owner'])->whereNotIn('id',$hiring)->get();
        foreach ( $buildings as $building) {
            $building_name=BuildingDescription::where(['building_id'=>$building->id,'language_id'=>1])->value('name');
            $not_hiring_buildings_array[$building->id] = $building_name;
        }
        $this->middleware('auth:admin');
        view()->share(array(
            'module_name'        => $this->module_name,
            'single_module_name' => $this->single_module_name,
            'route'              => $this->route,
            'index_fields'       => $this->index_fields,
            'create_fields'      => $this->create_fields,
            'update_fields'      => $this->update_fields,
            'status'        => ['active'=>'مفعل','not_active'=>'غير مفعل'],
            'two_user_types'        => ['union'=>'اتحاد مﻻك','user'=>'مستخدم عادى'],
            'two_building_types'        => ['union'=>'اتحاد مﻻك','owner'=>'للايجار'],
            'cities'        => $cities_array,
            'districts'        => $districts_array,
            'building_statuses'        => $building_statuses_array,
            'building_types'        => $building_types_array,
            'hiring_types'        => $hiring_types_array,
            'months'        => $months_array,
            'clients'        => $clients_array,
            'buildings'        => $buildings_array,
            'unions'        => $union_array,
            'not_hiring_buildings_array'        => $not_hiring_buildings_array,
            'languages'        => Language::all(),
            'setting'        => Setting::first(),
            'admin_count'=>Admin::count(),
            'user_count'=>User::where('type','user')->count(),
            'client_count'=>Client::count(),
            'city_count'=>City::count(),
            'district_count'=>District::count(),
            'building_count'=>Building::where('type','owner')->count(),
            'flat_count'=>Flat::count(),
            'hiring_count'=>Hiring::count(),
            'page_count'=>Page::count(),
            'lang_count'=>Language::count(),
            'social_count'=>Social::count(),
            'bank_count'=>Bank::count(),
            'union_count'=>Building::where('type','union')->count(),
            'union_user_count'=>User::where('type','union')->count(),
        ));

    }

	public function index() {
        $rows = $this->model->latest()->get();
        return view('admin.'.$this->route.'.index', compact('rows'));
    }

    public function create() {
        return view('admin.'.$this->route.'.create');   
    }

    public function store(Request $request) {
        $this->validate($request, $this->validation_func(1));
        $this->model->create($request->all());
        return redirect('admin/'.$this->route.'')->with('created', 'تمت الاضافة بنجاح');
    }

    public function edit($id) {
        $row = $this->model->find($id);
        return View('admin.'.$this->route.'.edit', compact('row'));
    }

    public function update($id, Request $request) {
        $this->validate($request, $this->validation_func(2,$id));
        $this->model->find($id)->update($request->all());
        return redirect('admin/'.$this->route.'')->with('updated','تم التعديل بنجاح');
    }

    public function destroy($id) {
        $this->model->find($id)->delete();
        return redirect('admin/'.$this->route.'')->with('deleted','تم الحذف بنجاح');
    }

    public function show($id)
    {
        $row = $this->model->find($id);
        return View('admin.'.$this->route.'.show', compact('row'));
    }

    public function Activate($id) {
        $row = $this->model->find($id);
        if($row->status == 'not_active') {
            $this->model->find($id)->update(['status' => 'active']);
            return back()->with('success' ,'تم الغاء التفعيل بنجاح');
        }
        else{
            $this->model->find($id)->update(['status' => 'not_active']);
            return back()->with('success' , 'تم التفعيل بنجاح');
        }
    }

}

